==> 0.1.0.tar.gz: lib/zhihu_daily.dart <==
library zhihu_daily;

import 'dart:convert';
import 'dart:async';
import 'package:http/http.dart';
import 'src/constants.dart';
import 'src/models.dart';
import 'src/utils.dart';

export 'src/models.dart';

class Zhihu {
  /// 获取启动界面图像
  Future<StartImage> fetchStartImage(
      {StartImageSize size: StartImageSize.size720}) async {
    var response =
        await get(buildUrl(ApiType.startImage, startImageSize: size));
    Map body = JSON.decode(response.body);
    var result;
    if (body.containsKey('text') && body.containsKey('img')) {
      result = new StartImage.fromJson(body);
    }
    return result;
  }

  /// 获取最新消息
  ///
  /// 返回结果中的第一个列表为头条，第二个列表是普通消息
  Future<List<List<News>>> fetchLatestNews() async {
    var response = await get(buildUrl(ApiType.latestNews));
    Map body = JSON.decode(response.body);
    var result = <List<News>>[];
    if (body.containsKey('date') && body.containsKey('stories')) {
      String date = body['date'];
      List list = body['top_stories'];
      List<News> topStories = <News>[];
      for (var item in list) {
        topStories.add(new News.fromJson(item, top: true)..date = date);
      }
      result.add(topStories);

      list = body['stories'];
      List<News> stories = <News>[];
      for (var item in list) {
        stories.add(new News.fromJson(item)..date = date);
      }
      result.add(stories);
    }
    return result;
  }

  /// 获取消息内容
  Future<Story> fetchStory(int storyId) async {
    var response = await get(buildUrl(ApiType.story, storyId: storyId));
    Map body = JSON.decode(response.body);
    var result;
    if (body.containsKey('body') && body.containsKey('id')) {
      result = new Story.fromJson(body);
    }
    return result;
  }

  /// 获取过往消息
  Future<List<News>> fetchOldNews({String date}) async {
    if (date == null) {
      date = today();
    }

    var response = await get(buildUrl(ApiType.oldNews, beforeDate: date));
    Map body = JSON.decode(response.body);
    var result = <News>[];
    if (body.containsKey('date') && body.containsKey('stories')) {
      String newsDate = body['date'];
      List list = body['stories'];
      for (var item in list) {
        result.add(new News.fromJson(item, top: true)..date = newsDate);
      }
    }
    return result;
  }

  /// 获取消息额外信息
  Future<StoryExtra> fetchStoryExtra(int storyId) async {
    var response = await get(buildUrl(ApiType.storyExtra, storyId: storyId));
    Map body = JSON.decode(response.body);
    var result;
    if (body.containsKey('popularity') && body.containsKey('comments')) {
      result = new StoryExtra.fromJson(body)..storyId = storyId;
    }
    return result;
  }

  /// 获取长评论
  Future<List<Comment>> fetchLongComments(int storyId) async {
    var response = await get(buildUrl(ApiType.longComments, storyId: storyId));
    Map body = JSON.decode(response.body);
    var result = <Comment>[];
    if (body.containsKey('comments')) {
      List list = body['comments'];
      for (var item in list) {
        result.add(new Comment.fromJson(item)..isLong = true);
      }
    }
    return result;
  }

  /// 获取短评论
  Future<List<Comment>> fetchShortComments(int storyId) async {
    var response = await get(buildUrl(ApiType.shortComments, storyId: storyId));
    Map body = JSON.decode(response.body);
    var result = <Comment>[];
    if (body.containsKey('comments')) {
      List list = body['comments'];
      for (var item in list) {
        result.add(new Comment.fromJson(item)..isShort = true);
      }
    }
    return result;
  }

  /// 获取主题日报列表
  Future<List<Theme>> fetchThemes() async {
    var response = await get(buildUrl(ApiType.themes));
    Map body = JSON.decode(response.body);
    var result = <Theme>[];
    if (body.containsKey('others') || body.containsKey('subscribed')) {
      List list = body['others'];
      List list2 = body['subscribed'];
      list.addAll(list2);
      for (var item in list) {
        result.add(new Theme.fromJson(item));
      }
    }
    return result;
  }

  /// 获取主题日报内容
  Future<ThemeContent> fetchThemeContent(int themeId) async {
    var response = await get(buildUrl(ApiType.themeContent, themeId: themeId));
    Map body = JSON.decode(response.body);
    var result;
    if (body.containsKey('name') && body.containsKey('stories')) {
      result = new ThemeContent.fromJson(body);
    }
    return result;
  }
}

==> 0.3.0.tar.gz: lib/zhihu_daily.dart <==
/// 非官方知乎日报 Dart SDK，所有API信息都取自非官方的[知乎日报API分析](https://github.com/izzyleung/ZhihuDailyPurify/wiki/%E7%9F%A5%E4%B9%8E%E6%97%A5%E6%8A%A5-API-%E5%88%86%E6%9E%90)。
library zhihu_daily;

import 'dart:convert';
import 'dart:async';

import 'package:http/http.dart';

import 'src/constant.dart';
import 'src/model.dart';
import 'src/util.dart';
import 'src/interface.dart';
import 'src/extractor.dart';

export 'src/model.dart';

/// 知乎日报Api默认实现类
class ZhihuDaily implements ZhihuDailyApi {
  /// 获取启动界面图像
  Future<StartImage> fetchStartImage(
      {StartImageSize size: StartImageSize.size720}) async {
    var response =
        await get(buildUrl(ApiType.startImage, startImageSize: size));
    Map body = JSON.decode(response.body);
    return extractStartImage(body);
  }

  /// 获取最新消息
  ///
  /// 返回结果中的第一个列表为头条，第二个列表是普通消息
  Future<List<List<News>>> fetchLatestNews() async {
    var response = await get(buildUrl(ApiType.latestNews));
    Map body = JSON.decode(response.body);
    return extractLatestNews(body);
  }

  /// 获取消息内容
  Future<Story> fetchStory(int storyId) async {
    var response = await get(buildUrl(ApiType.story, storyId: storyId));
    Map body = JSON.decode(response.body);
    return extractStory(body);
  }

  /// 获取过往消息
  Future<List<News>> fetchOldNews({String date}) async {
    var response = await get(buildUrl(ApiType.oldNews, beforeDate: date));
    Map body = JSON.decode(response.body);
    return extractOldNews(body);
  }

  /// 获取消息额外信息
  Future<StoryExtra> fetchStoryExtra(int storyId) async {
    var response = await get(buildUrl(ApiType.storyExtra, storyId: storyId));
    Map body = JSON.decode(response.body);
    return extractStoryExtra(body, storyId);
  }

  /// 获取长评论
  Future<List<Comment>> fetchLongComments(int storyId) async {
    var response = await get(buildUrl(ApiType.longComments, storyId: storyId));
    Map body = JSON.decode(response.body);
    return extractLongComments(body);
  }

  /// 获取短评论
  Future<List<Comment>> fetchShortComments(int storyId) async {
    var response = await get(buildUrl(ApiType.shortComments, storyId: storyId));
    Map body = JSON.decode(response.body);
    return extractShortComments(body);
  }

  /// 获取主题日报列表
  Future<List<Theme>> fetchThemes() async {
    var response = await get(buildUrl(ApiType.themes));
    Map body = JSON.decode(response.body);
    return extractThemes(body);
  }

  /// 获取主题日报内容
  Future<ThemeContent> fetchThemeContent(int themeId) async {
    var response = await get(buildUrl(ApiType.themeContent, themeId: themeId));
    Map body = JSON.decode(response.body);
    return extractThemeContent(body);
  }
}
